pub enum TargetError {
UnknownTarget(String),
InvalidTargetVersion(SpirvTarget),
InvalidNagaVariant(String),
}Variants
UnknownTarget(String)
If during parsing a target variant returns UnknownTarget, further variants will attempt to parse the string.
Returning another error means that you have recognized the target but something else is invalid, and we should
abort the parsing with your error.
InvalidTargetVersion(SpirvTarget)
InvalidNagaVariant(String)